@@ -35,20 +35,21 @@ where
         // Write level and target
         let level = *event.metadata().level();
         let target = event.metadata().file().expect("will never be `None`");
-        write!(
+        let span_separation_string = "\t ➤ ";
+        writeln!(
             writer,
-            "{} [{}:L{}]:\n\t",
+            "{} [{}:L{}]:",
             level,
             target,
             event.metadata().line().expect("will never be `None`")
         )?;
 
-        let mut indentation = 0;
+        write!(writer, "{}", span_separation_string)?;
+
+        // let mut span_count = 0;
         // Write spans and fields of each span
         ctx.visit_spans(|span| {
-            let indentation_string = "\t".repeat(indentation);
-            writeln!(writer, "{}{}", indentation_string, span.name())?;
-            indentation += 1;
+            write!(writer, "{} ", span.name())?;
 
             let ext = span.extensions();
 
@@ -62,10 +63,10 @@ where
                 .expect("will never be `None`");
 
             if !fields.is_empty() {
-                writeln!(writer, "{{{}}}", fields)?;
+                write!(writer, "{{{}}}", fields)?;
             }
 
-            write!(writer, "{}", indentation_string.repeat(2))?;
+            write!(writer, "\n{}", span_separation_string)?;
 
             Ok(())
         })?;
@@ -78,7 +79,7 @@ where
 }
 
 /// Initialise logger for tests, this is run only once, even if called multiple times.
-pub fn init_logger() {
+pub fn init_test_logger() {
     INIT.call_once(|| {
         fmt()
             // NOTE: uncomment this line for pretty printed log output.
@@ -103,7 +104,6 @@ pub async fn create_test_client_with(
     optional_keypair: Option<Keypair>,
     timeout: Option<u64>,
 ) -> Result<Client> {
-    init_logger();
     let root_dir = tempdir().map_err(|e| eyre::eyre!(e.to_string()))?;
     let timeout = timeout.map(Duration::from_secs);
     let (genesis_key, bootstrap_nodes) = read_network_conn_info()?;
